@@ -30,7 +30,7 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgName, QList<const Partition*>& partList, qint32& peSize, QList<Device*> devices)
+CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgName, std::vector<const Partition*>& partList, qint32& peSize, QList<Device*> devices)
     : VolumeGroupDialog(parent, vgName, partList)
     , m_PESize(peSize)
     , m_Devices(devices)
@@ -50,7 +50,7 @@ CreateVolumeGroupDialog::CreateVolumeGroupDialog(QWidget* parent, QString& vgNam
 
 void CreateVolumeGroupDialog::setupDialog()
 {
-    for (const auto &p : LVM::pvList) // FIXME: qAsConst
+    for (const auto &p : qAsConst(LVM::pvList))
         if (!p.isLuks() && p.vgName() == QString() && !LvmDevice::s_DirtyPVs.contains(p.partition()))
             dialogWidget().listPV().addPartition(*p.partition(), false);
 }
@@ -66,7 +66,7 @@ void  CreateVolumeGroupDialog::accept()
     QString& tname = targetName();
     tname = dialogWidget().vgName().text();
 
-    targetPVList() << dialogWidget().listPV().checkedItems();
+    targetPVList().insert(targetPVList().end(), dialogWidget().listPV().checkedItems().begin(), dialogWidget().listPV().checkedItems().end());
 
     qint32& pesize = peSize();
     pesize = dialogWidget().spinPESize().value();
