@@ -80,9 +80,9 @@ void NewDialog::setupDialog()
             fsNames.append(fs->name());
     }
 
-    qSort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
+    std::sort(fsNames.begin(), fsNames.end(), caseInsensitiveLessThan);
 
-    foreach (const auto &fsName, fsNames)
+    for (const auto &fsName : qAsConst(fsNames))
         dialogWidget().comboFileSystem().addItem(createFileSystemColor(FileSystem::typeForName(fsName), 8), fsName);
 
     QString selected = FileSystem::nameForType(GuiHelpers::defaultFileSystem());
